@@ -1,5 +1,7 @@
 package TestSupport;
 
+use strict;
+use warnings;
 use File::Temp qw(tempdir);
 use File::Path;
 use File::Basename;
@@ -7,7 +9,8 @@ use File::Copy qw(move);
 use autodie;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(create_test_files delete_test_files move_test_files $dir);
+our @EXPORT_OK = qw(create_test_files delete_test_files move_test_files
+  modify_attrs_on_test_files $dir);
 
 our $dir = tempdir( CLEANUP => 1 );
 my $size = 1;
@@ -47,4 +50,13 @@ sub move_test_files {
     }
 }
 
+sub modify_attrs_on_test_files{
+    my (@files) = @_;
+
+    for my $file (@files) {
+        my $full_file = File::Spec->catfile( $dir, $file );
+        chmod 0750, $full_file or die "Error chmod on $full_file: $!";
+    }
+}
+
 1;
